@@ -32,14 +32,12 @@ def _run_tracker(
     destination: Destination,
     args: argparse.Namespace,
     post_run_message: Optional[str] = None,
-    follow_fork: bool = False,
-    trace_python_allocators: bool = False,
 ) -> None:
     try:
         kwargs = {}
-        if follow_fork:
+        if args.follow_fork:
             kwargs["follow_fork"] = True
-        if trace_python_allocators:
+        if args.trace_python_allocators:
             kwargs["trace_python_allocators"] = True
         tracker = Tracker(destination=destination, native_traces=args.native, **kwargs)
     except OSError as error:
@@ -69,6 +67,7 @@ def _run_tracker(
 def _child_process(
     port: int,
     native: bool,
+    trace_python_allocators: bool,
     run_as_module: bool,
     run_as_cmd: bool,
     quiet: bool,
@@ -77,6 +76,8 @@ def _child_process(
 ) -> None:
     args = argparse.Namespace(
         native=native,
+        trace_python_allocators=trace_python_allocators,
+        follow_fork=False,
         run_as_module=run_as_module,
         run_as_cmd=run_as_cmd,
         quiet=quiet,
@@ -94,14 +95,14 @@ def _run_child_process_and_attach(args: argparse.Namespace) -> None:
         raise MemrayCommandError(f"Invalid port: {port}", exit_code=1)
 
     arguments = (
-        f"{port},{args.native},{args.run_as_module},{args.run_as_cmd},{args.quiet},"
-        f'"{args.script}",{args.script_args}'
+        f"{port},{args.native},{args.trace_python_allocators},"
+        f"{args.run_as_module},{args.run_as_cmd},{args.quiet},"
+        f"{args.script!r},{args.script_args}"
     )
     tracked_app_cmd = [
         sys.executable,
         "-c",
-        f"from memray.commands.run import _child_process;"
-        f"_child_process({arguments})",
+        f"from memray.commands.run import _child_process;_child_process({arguments})",
     ]
     with contextlib.suppress(KeyboardInterrupt):
         with subprocess.Popen(
@@ -169,8 +170,6 @@ def _run_with_file_output(args: argparse.Namespace) -> None:
             destination=destination,
             args=args,
             post_run_message=example_report_generation_message,
-            follow_fork=args.follow_fork,
-            trace_python_allocators=args.trace_python_allocators,
         )
     except OSError as error:
         raise MemrayCommandError(str(error), exit_code=1)
@@ -299,8 +298,9 @@ class RunCommand:
             parser.error("The --live-port argument requires --live-remote")
         if args.follow_fork is True and (args.live_mode or args.live_remote_mode):
             parser.error("--follow-fork cannot be used with the live TUI")
-        if args.run_as_cmd and pathlib.Path(args.script).exists():
-            parser.error("remove the option -c to run a file")
+        with contextlib.suppress(OSError):
+            if args.run_as_cmd and pathlib.Path(args.script).exists():
+                parser.error("remove the option -c to run a file")
 
         self.validate_target_file(args)
 
